@@ -1,41 +1,14 @@
 from __future__ import annotations
 
-import os
-import io
-
-from pathlib import PosixPath, WindowsPath, _NormalAccessor, Path, PurePath, _ignore_error
-from pathlib import _make_selector as _sync_make_selector
-from typing import Optional, List, Union, AsyncIterable, Iterable, IO
-from os import stat_result, PathLike
-from stat import S_ISDIR, S_ISLNK, S_ISREG, S_ISSOCK, S_ISBLK, S_ISCHR, S_ISFIFO
-
-from anyio import open_file
-
-#from aiopath.selectors import _make_selector
-#from aiopath.wrap import coro_as_method_coro, func_as_method_coro, to_thread, method_as_method_coro, func_to_async_func
-#from aiopath.handle import IterableAIOFile, get_handle
-#from aiopath.scandir import EntryWrapper, scandir_async, _scandir_results
-#from aiopath.types import Final, Literal, FileMode
-
-
-from .aiopathz.selectors import _make_selector
-from .aiopathz.wrap import coro_as_method_coro, func_as_method_coro, to_thread, method_as_method_coro, func_to_async_func
-from .aiopathz.handle import IterableAIOFile, get_handle
-from .aiopathz.scandir import EntryWrapper, scandir_async, _scandir_results
-from .aiopathz.types import Final, Literal, FileMode
-
 from lazy.serialize import Serialize
+from stat import S_ISDIR, S_ISLNK, S_ISREG, S_ISSOCK, S_ISBLK, S_ISCHR, S_ISFIFO
+from typing import ClassVar
+
 from .types import *
-from .flavours import _async_sync_windows_flavour, _async_sync_posix_flavour
-
-DEFAULT_ENCODING: Final[str] = 'utf-8'
-ON_ERRORS: Final[str] = 'ignore'
-NEWLINE: Final[str] = '\n'
-
-
-"""
-Taken from https://github.com/alexdelorenzo/aiopath/blob/Python-3.9/aiopath/path.py
-"""
+from .base_imports import *
+from .aiopathz.selectors import _make_selector
+from .aiopathz.scandir import EntryWrapper, scandir_async, _scandir_results
+from .flavours import _pathz_windows_flavour, _pathz_posix_flavour
 
 
 def scandir_sync(*args, **kwargs) -> Iterable[EntryWrapper]:
@@ -47,7 +20,7 @@ close = func_to_async_func(os.close)
 sync_close = os.close
 
 
-class _PathzAccessor(_NormalAccessor):
+class _PathzAccessor(NormalAccessor):
     # Sync methods
     stat = os.stat
     lstat = os.lstat
@@ -62,9 +35,9 @@ class _PathzAccessor(_NormalAccessor):
     async_listdir = func_as_method_coro(os.listdir)
     async_chmod = func_as_method_coro(os.chmod)
 
-    if hasattr(_NormalAccessor, 'lchmod'):
-        lchmod = _NormalAccessor.lchmod
-        async_lchmod = method_as_method_coro(_NormalAccessor.lchmod)
+    if hasattr(NormalAccessor, 'lchmod'):
+        lchmod = NormalAccessor.lchmod
+        async_lchmod = method_as_method_coro(NormalAccessor.lchmod)
 
     mkdir = os.mkdir
     unlink = os.unlink
@@ -72,24 +45,24 @@ class _PathzAccessor(_NormalAccessor):
     async_mkdir = func_as_method_coro(os.mkdir)
     async_unlink = func_as_method_coro(os.unlink)
 
-    if hasattr(_NormalAccessor, 'link'):
-        link = _NormalAccessor.link
-        async_link = method_as_method_coro(_NormalAccessor.link)
+    if hasattr(NormalAccessor, 'link'):
+        link = NormalAccessor.link
+        async_link = method_as_method_coro(NormalAccessor.link)
 
     rmdir = os.rmdir
     rename = os.rename
     replace = os.replace
-    symlink = staticmethod(_NormalAccessor.symlink)
+    symlink = staticmethod(NormalAccessor.symlink)
     utime = os.utime
-    readlink = _NormalAccessor.readlink
+    readlink = NormalAccessor.readlink
     remove = os.remove
 
     async_rmdir = func_as_method_coro(os.rmdir)
     async_rename = func_as_method_coro(os.rename)
     async_replace = func_as_method_coro(os.replace)
-    async_symlink = staticmethod(method_as_method_coro(_NormalAccessor.symlink))
+    async_symlink = staticmethod(method_as_method_coro(NormalAccessor.symlink))
     async_utime = func_as_method_coro(os.utime)
-    async_readlink = method_as_method_coro(_NormalAccessor.readlink)
+    async_readlink = method_as_method_coro(NormalAccessor.readlink)
     async_remove = func_as_method_coro(os.remove)
 
 
@@ -136,11 +109,18 @@ _pathz_accessor = _PathzAccessor()
 
 
 class PathzPurePath(PurePath):
+    _prefix: str = None
+    _provider: str = None
+    _win_pathz: ClassVar = 'PurePathzWindowsPath'
+    _posix_pathz: ClassVar = 'PurePathzPosixPath'
+
     def _init(self, template: Optional[PurePath] = None):
         self._accessor = _pathz_accessor
 
     def __new__(cls, *args):
-        if cls is PathzPurePath: cls = PurePathzWindowsPath if os.name == 'nt' else PurePathzPosixPath
+        if cls is PathzPurePath or issubclass(cls, PathzPurePath): 
+            cls = cls._win_pathz if os.name == 'nt' else cls._posix_pathz
+            cls = globals()[cls]
         return cls._from_parts(args)
 
 
@@ -149,7 +129,7 @@ class PurePathzPosixPath(PathzPurePath):
     On a POSIX system, instantiating a PurePath should return this object.
     However, you can also instantiate it directly on any system.
     """
-    _flavour = _async_sync_posix_flavour
+    _flavour = _pathz_posix_flavour
     __slots__ = ()
 
 
@@ -158,7 +138,7 @@ class PurePathzWindowsPath(PathzPurePath):
     On a Windows system, instantiating a PurePath should return this object.
     However, you can also instantiate it directly on any system.
     """
-    _flavour = _async_sync_windows_flavour
+    _flavour = _pathz_windows_flavour
     __slots__ = ()
 
 
@@ -166,8 +146,12 @@ class PathzPath(Path, PathzPurePath):
     """
     Our customized class that incorporates both sync and async methods
     """
-    _flavour = _async_sync_windows_flavour if os.name == 'nt' else _async_sync_posix_flavour
+    _flavour = _pathz_windows_flavour if os.name == 'nt' else _pathz_posix_flavour
     _accessor = _pathz_accessor
+    _prefix = None
+    _provider = None
+    _win_pathz: ClassVar = 'PathzWindowsPath'
+    _posix_pathz: ClassVar = 'PathzPosixPath'
 
     def _init(self, template: Optional[PathzPath] = None):
         self._accessor = _pathz_accessor
@@ -175,8 +159,10 @@ class PathzPath(Path, PathzPurePath):
         self._fileio = None
 
     def __new__(cls, *args, **kwargs):
-        if cls is PathzPath: cls = PathzWindowsPath if os.name == 'nt' else PathzPosixPath
-
+        #if cls is PathzPath: cls = PathzWindowsPath if os.name == 'nt' else PathzPosixPath
+        if cls is PathzPath or issubclass(cls, PathzPath): 
+            cls = cls._win_pathz if os.name == 'nt' else cls._posix_pathz
+            cls = globals()[cls]
         self = cls._from_parts(args, init=False)
         if not self._flavour.is_supported:
             name: str = cls.__name__
@@ -189,9 +175,53 @@ class PathzPath(Path, PathzPurePath):
     def _path(self) -> str:
         return str(self)
     
+
+    @property
+    def _cloudpath(self) -> str:
+        """
+        Returns the `__fspath__` string representation without the uri_scheme
+        """
+        return None
+    
+    @property
+    def _bucket(self) -> str:
+        """
+        Returns the `__fspath__` string representation without the uri_scheme
+        """
+        return None
+    
+    @property
+    def _bucketstr(self) -> Optional[str]:
+        """
+        Returns the `__fspath__` string representation without the uri_scheme
+        """
+        return None
+    
+    @property
+    def _pathkeys(self) -> Optional[str]:
+        """
+        Returns the `__fspath__` string representation without the uri_scheme
+        """
+        return None
+    
+    @property
+    def _cloudstr(self) -> Optional[str]:
+        """
+        Reconstructs the proper cloud URI
+        """
+        return None
+    
+    @property
+    def posix_(self):
+        """Return the string representation of the path with forward (/)
+        slashes."""
+        f = self._flavour
+        return str(self).replace(f.sep, '/')
+
     @property
     def string(self) -> str:
-        return str(self)
+        return self.posix_
+
     
     @property
     def filename_(self) -> str:
